@@ -1,4 +1,4 @@
-class UnsupportedProtocolError(Exception):
+class ProtocolUnsopportError(Exception):
     def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
@@ -12,6 +12,12 @@ class NameNotFoundError(Exception):
     def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
-class ConfigError(Exception):
+
+class ParamInvalidError(Exception):
+    def __init__(self, *args: object) -> None:
+        super().__init__(*args)
+
+
+class ParamCountInvalidError(Exception):
     def __init__(self, *args: object) -> None:
         super().__init__(*args)
